﻿/*
Code written/modified by: Dean Lunz (aka Crated by: X)
Web: http://www.createdbyx.com/ 
NOTICE: The code in this file does not fall under the zeeAni licence.
  
 Original source for this code comes from the tutorial "Animation Sets" found on the
 http://www.codeanxiety.com/ website.
 Original Code Author: Justin "Kukyona" O'Dell -> http://codeanxiety.com/user/Profile.aspx?UserID=2100
 */
using System;
using Microsoft.Xna.Framework;

namespace zeeAni
{
    /// <summary>
    /// Class to store our animation information.
    /// </summary>
    public sealed class AnimationInfo :ICloneable
    {
        /// <summary>
        /// Holds the start frame value.
        /// </summary>
        private int startFrame = 0;
        /// <summary>
        /// Holds the end frame value.
        /// </summary>
        private int endFrame = 0;
        /// <summary>
        /// Holds teh frame rate value.
        /// </summary>
        private float frameRate = 15f;
        /// <summary>
        /// Holds a looping value.
        /// </summary>
        /// <remarks>Used to determine if the animation should automatically start from the beginning.</remarks>
        private bool loops = false;

        /// <summary>
        /// Default constructor.
        /// </summary>
        /// <param name="startFrame">The index of the first frame in the animation.</param>
        /// <param name="endFrame">The index of the last frame in the animation.</param>
        /// <param name="frameRate">The rate of how many frames are played in one second.</param>
        /// <param name="loops">Whether or not this animation should start over when it finishes.</param>
        public AnimationInfo(int startFrame, int endFrame, float frameRate, bool loops)
        {
            this.startFrame = startFrame;
            this.endFrame = endFrame;
            this.frameRate = frameRate < 1 ? 1 : frameRate;
            this.loops = loops;
        }

        /// <summary>
        /// Gets/Sets the index of the first frame in the animation.
        /// </summary>
        public int StartFrame
        {
            get { return startFrame; }
            set { this.startFrame = value; }
        }

        /// <summary>
        /// Gets/Sets the index of the last frame in the animation.
        /// </summary>
        public int EndFrame
        {
            get { return endFrame; }
            set { this.endFrame = value; }
        }

        /// <summary>
        /// Gets/Sets the rate of how many frames are played in one second.
        /// </summary>
        public float FrameRate
        {
            get { return frameRate; }
            set { this.frameRate = value; }
        }

        /// <summary>
        /// Gets/Sets whether or not this animation should start over when it finishes.
        /// </summary>
        public bool Loops
        {
            get { return loops; }
            set { this.loops = value; }
        }

        #region ICloneable Members

        /// <summary>
        /// Clones the object.
        /// </summary>
        /// <returns>Return a new copy of the object with the same values.</returns>
        public object Clone()
        {
            return new AnimationInfo(this.startFrame,this.endFrame,this.frameRate,this.loops);
        }

        #endregion
    }
}
