using System;
using System.Collections.Generic;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Net;
using Microsoft.Xna.Framework.Storage;

namespace zeeAni_Example1
{
    /// <summary>
    /// This is the main type for your game
    /// </summary>
    public class Game1 : Microsoft.Xna.Framework.Game
    {
        GraphicsDeviceManager graphics;
        SpriteBatch spriteBatch;
        SpriteFont font;
        zeeAni.AnimationSet<string, zeeAni.SpriteFrame> animation;


        public Game1()
        {
            graphics = new GraphicsDeviceManager(this);
            Content.RootDirectory = "Content";
        }

        /// <summary>
        /// Allows the game to perform any initialization it needs to before starting to run.
        /// This is where it can query for any required services and load any non-graphic
        /// related content.  Calling base.Initialize will enumerate through any components
        /// and initialize them as well.
        /// </summary>
        protected override void Initialize()
        {
            // create the animation
            this.animation = new zeeAni.AnimationSet<string, zeeAni.SpriteFrame>();

            base.Initialize();
        }

        /// <summary>
        /// LoadContent will be called once per game and is the place to load
        /// all of your content.
        /// </summary>
        protected override void LoadContent()
        {
            // Create a new SpriteBatch, which can be used to draw textures.
            spriteBatch = new SpriteBatch(GraphicsDevice);

            // load font
            this.font = this.Content.Load<SpriteFont>("CourierNew");

            // load animation set from content asset
            // NOTE: Until I can come up with a way to specify a type (that uses generics in it's decloration) during the content.load<> call
            // the readers are restricted to string as a key accessor and SpriteFrame as a frame type
            this.animation = this.Content.Load<zeeAni.AnimationSet<string, zeeAni.SpriteFrame>>("LinkDefault");

            // the animation is not playing by default so we will start playing it now
            this.animation.Play("Walking South");
        }

        /// <summary>
        /// UnloadContent will be called once per game and is the place to unload
        /// all content.
        /// </summary>
        protected override void UnloadContent()
        {
            // TODO: Unload any non ContentManager content here
        }

        /// <summary>
        /// Allows the game to run logic such as updating the world,
        /// checking for collisions, gathering input, and playing audio.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Update(GameTime gameTime)
        {
            // Allows the game to exit
            if (GamePad.GetState(PlayerIndex.One).Buttons.Back == ButtonState.Pressed)
                this.Exit();

            KeyboardState kbstate = Keyboard.GetState();
            if (kbstate.IsKeyDown(Keys.Down)) this.animation.Play("Walking South");
            if (kbstate.IsKeyDown(Keys.Up)) this.animation.Play("Walking North");
            if (kbstate.IsKeyDown(Keys.Left)) this.animation.Play("Walking West");
            if (kbstate.IsKeyDown(Keys.Right)) this.animation.Play("Walking East");
            if (kbstate.IsKeyDown(Keys.Escape)) this.Exit();

            // update the animation
            this.animation.Update(gameTime);
            
            base.Update(gameTime);
        }

        /// <summary>
        /// This is called when the game should draw itself.
        /// </summary>
        /// <param name="gameTime">Provides a snapshot of timing values.</param>
        protected override void Draw(GameTime gameTime)
        {
            graphics.GraphicsDevice.Clear(Color.CornflowerBlue);

            // Draw the animation
            this.spriteBatch.Begin();
           
            // get the current animation frame
            zeeAni.SpriteFrame frame = this.animation.CurrentFrame;

            // You can use the typical draw method found on the spritebat object ...
            //this.spriteBatch.Draw(frame.Texture, Vector2.One * 400, frame.SourceRectangle, frame.Color, frame.Rotation,
            //                      frame.Origin, frame.Scale, frame.Effect, 0);
            // ... or you can use the draw method on the frame as a simpler draw call
            frame.Draw(this.spriteBatch, Vector2.One * 400);      
            
            // draw info text
            this.spriteBatch.DrawString(this.font, "Use keyboard arrow keys \r\nto change the animation", Vector2.Zero, Color.Red);
            this.spriteBatch.End();
            
            base.Draw(gameTime);
        }
    }
}
